/// <reference path="../native.ts" />
/// <reference path="../object.ts" />

namespace trusted.cms {
    /**
     * Wrap CMS_CertInfo
     *
     * @export
     * @class CertInfo
     * @extends {BaseObject<native.CMS.CertInfo>}
     */
    export class CertInfo extends BaseObject<native.CMS.CertInfo> {

        /**
         * Creates an instance of CertInfo.
         *
         * @param {native.CMS.CertInfo} handle
         *
         * @memberOf CertInfo
         */
        constructor(nativeHandle?: native.CMS.CertInfo) {
            super();

            if (nativeHandle instanceof native.CMS.CertInfo) {
                this.handle = nativeHandle;
            }
            else {
                this.handle = new native.CMS.CertInfo();
            }
        }

        /**
         * Return issuer name
         *
         * @readonly
         * @type {string}
         * @memberOf CertInfo
         */
         get issuerName(): string {
            return this.handle.getIssuerName();
        }

        /**
         * Return serial number of certificate
         *
         * @readonly
         * @type {string}
         * @memberOf CertInfo
         */
         get serialNumber(): string {
            return this.handle.getSerialNumber().toString();
        }
    }
}
