/// <reference path="../native.ts" />
/// <reference path="../object.ts" />

namespace trusted.pki {

    const DEFAULT_DATA_FORMAT: DataFormat = DataFormat.DER;

    /**
     * Wrap PKCS12
     *
     * @export
     * @class PKCS12
     * @extends {BaseObject<native.PKI.PKCS12>}
     */
    export class PKCS12 extends BaseObject<native.PKI.PKCS12> {
        /**
         * Load PKCS12 from file
         *
         * @static
         * @param {string} filename File location
         * @returns {PKCS12}
         *
         * @memberOf PKCS12
         */
        public static load(filename: string): PKCS12 {
            const pkcs12: PKCS12 = new PKCS12();
            pkcs12.handle.load(filename);
            return pkcs12;
        }

        /**
         * Creates an instance of PKCS12.
         * @param {native.PKI.PKCS12} [param]
         *
         * @memberOf Certificate
         */
        constructor(param?: native.PKI.PKCS12) {
            super();
            if (param instanceof native.PKI.PKCS12) {
                this.handle = param;
            } else {
                this.handle = new native.PKI.PKCS12();
            }
        }

        /**
         * Load PKCS12 from file
         *
         * @param {string} filename File location
         *
         * @memberOf PKCS12
         */
        public load(filename: string): void {
            this.handle.load(filename);
        }

        /**
         * Write PKCS12 to file
         *
         * @param {string} filename File location
         *
         * @memberOf PKCS12
         */
        public save(filename: string): void {
            this.handle.save(filename);
        }
    }
}
